DataLayout

Struct DataLayout 

pub struct DataLayout { /* private fields */ }
Target specific data layout provided by LLVM.

Implementations

Source

impl DataLayout

pub fn new(layout: &str) -> Self

Build DataLayout as described by layout.

Warning: Aborts if layout is not a valid data layout string.

pub fn host() -> Result<Self>

Build DataLayout of this (the host) machine.

pub fn from_module_layout(ctx: &Context, module: ModuleOp) -> Result<Self>

Build DataLayout based on a module’s layout, if it has one. Falls back to Self::host if module doesn’t have a layout set.

pub fn string_representation(&self) -> String

The data layout string of this layout.

pub fn type_size_in_bits( &mut self, ctx: &Context, ty: TypeHandle, ) -> Result<u64>

The number of bits that ty holds.

pub fn type_store_size(&mut self, ctx: &Context, ty: TypeHandle) -> Result<u64>

The number of bytes that the data of ty uses.

pub fn type_alloc_size(&mut self, ctx: &Context, ty: TypeHandle) -> Result<u64>

The number of bytes that one element of an array of ty uses.

pub fn abi_type_align(&mut self, ctx: &Context, ty: TypeHandle) -> Result<u32>

The alignment in bytes of ty, provided by the ABI.

pub fn packs_exactly(&mut self, ctx: &Context, ty: TypeHandle) -> Result<bool>

Does an array of ty hold its elements with no padding between them?

This is equivalent to Self::type_store_size == Self::type_alloc_size